<html lang="en" xmlns="http://www.w3.org/1999/xhtml" xml:lang="en">
<head>
    <meta content="http://www.w3.org/1999/xhtml; charset=utf-8" http-equiv="Content-Type"/>
    <title>{{ title }}</title>
    <meta content="{{ author }}" name="author"/>
    <meta content="{{ description }}" name="description"/>
</head>
<body>
{{ content }}
</body>
</html>
